Change Log
==========

| All notable changes to this project will be documented in this file.
| This project adheres to `Semantic Versioning <http://semver.org/>`__.
| You should `Keep a CHANGELOG <http://keepachangelog.com/>`__, too!

`Next Release <https://github.com/sfischer13/python-arpa/compare/0.1.0...HEAD>`__
---------------------------------------------------------------------------------

Added
~~~~~

Changed
~~~~~~~

Deprecated
~~~~~~~~~~

Fixed
~~~~~

Removed
~~~~~~~

Security
~~~~~~~~

0.1.0 - 2015-07-04
------------------

Added
~~~~~

-  minimum viable product
